/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.yifu.archives.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yifu.cloud.plus.v1.yifu.archives.entity.TEmpDisabilityInfo;
import com.yifu.cloud.plus.v1.yifu.archives.service.TEmpDisabilityInfoService;
import com.yifu.cloud.plus.v1.yifu.archives.vo.DisabilitySearchVo;
import com.yifu.cloud.plus.v1.yifu.common.core.util.ErrorMessage;
import com.yifu.cloud.plus.v1.yifu.common.core.util.R;
import com.yifu.cloud.plus.v1.yifu.common.log.annotation.SysLog;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import lombok.SneakyThrows;
import lombok.extern.log4j.Log4j2;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.Arrays;
import java.util.List;


/**
 * 员工伤残信息表
 *
 * @author fxj
 * @date 2022-06-18 09:39:46
 */
@Log4j2
@RestController
@RequiredArgsConstructor
@RequestMapping("/tempdisabilityinfo" )
@Tag(name = "员工伤残信息表管理")
public class TEmpDisabilityInfoController {

    private final TEmpDisabilityInfoService tEmpDisabilityInfoService;

    /**
     * 分页查询
     * @param page 分页对象
     * @param searchVo 员工伤残信息表
     * @return
     */
    @Operation(summary = "分页查询", description = "分页查询")
    @GetMapping("/page" )
    public R<IPage<TEmpDisabilityInfo>> getTEmpDisabilityInfoPage(Page page, DisabilitySearchVo searchVo) {
        return R.ok(tEmpDisabilityInfoService.pageDiy(page, searchVo));
    }

	/**
	 * 不分页查询
	 * @param searchVo 员工伤残信息表
	 * @return
	 */
	@Operation(summary = "不分页查询", description = "不分页查询")
	@PostMapping("/noPage" )
	public R<List<TEmpDisabilityInfo>> getTEmpDisabilityInfoNoPage(@RequestBody DisabilitySearchVo searchVo) {
		return R.ok(tEmpDisabilityInfoService.getTEmpDisabilityInfoNoPage(searchVo));
	}

	/**
     * 通过id查询员工伤残信息表
     * @param id id
     * @return R
     */
    @Operation(summary = "通过id查询", description = "通过id查询hasPermission('archives_tempdisabilityinfo_get')")
    @GetMapping("/{id}" )
    @PreAuthorize("@pms.hasPermission('archives_tempdisabilityinfo_get')" )
    public R<TEmpDisabilityInfo> getById(@PathVariable("id" ) String id) {
        return R.ok(tEmpDisabilityInfoService.getById(id));
    }

    /**
     * 新增员工伤残信息表
     * @param tEmpDisabilityInfo 员工伤残信息表
     * @return R
     */
    @Operation(summary = "新增员工伤残信息表", description = "新增员工伤残信息表hasPermission('archives_tempdisabilityinfo_add')")
    @SysLog("新增员工伤残信息表" )
    @PostMapping
    @PreAuthorize("@pms.hasPermission('archives_tempdisabilityinfo_add')" )
    public R<Boolean> save(@RequestBody TEmpDisabilityInfo tEmpDisabilityInfo) {

        return tEmpDisabilityInfoService.saveDiy(tEmpDisabilityInfo);
    }

    /**
     * 修改员工伤残信息表
     * @param tEmpDisabilityInfo 员工伤残信息表
     * @return R
     */
    @Operation(summary = "修改员工伤残信息表", description = "修改员工伤残信息表hasPermission('archives_tempdisabilityinfo_edit')")
    @SysLog("修改员工伤残信息表" )
    @PutMapping
    @PreAuthorize("@pms.hasPermission('archives_tempdisabilityinfo_edit')" )
    public R<Boolean> updateById(@RequestBody TEmpDisabilityInfo tEmpDisabilityInfo) {
        return tEmpDisabilityInfoService.updateByIdDiy(tEmpDisabilityInfo);
    }

    /**
     * 通过id删除员工伤残信息表
     * @param id id
     * @return R
     */
    @Operation(summary = "通过id删除员工伤残信息表", description = "通过id删除员工伤残信息表hasPermission('archives_tempdisabilityinfo_del')")
    @SysLog("通过id删除员工伤残信息表" )
    @DeleteMapping("/{id}" )
    @PreAuthorize("@pms.hasPermission('archives_tempdisabilityinfo_del')" )
    public R<Boolean> removeById(@PathVariable String id) {
        return R.ok(tEmpDisabilityInfoService.removeById(id));
    }


	/**
	 * 通过ids删除员工伤残信息表
	 * @param ids id
	 * @return R
	 */
	@Operation(description = "通过ids删除员工伤残信息表hasPermission('archives_tempdisabilityinfo_del_batch')")
	@SysLog("通过ids删除员工伤残信息表" )
	@DeleteMapping("/removeByIds" )
	@PreAuthorize("@pms.hasPermission('archives_tempdisabilityinfo_del_batch')" )
	public R<Boolean> removeByIds(@RequestBody(required = true)  String[] ids) {
		List<String> idList = Arrays.asList(ids);
		return R.ok(tEmpDisabilityInfoService.removeByIds(idList));
	}
	/**
	 * 批量新增员工伤残信息
	 *
	 * @param file
	 * @return
	 * @Author fxj
	 * @Date 2019-08-16
	 **/
	@SneakyThrows
	@Operation(description = "批量新增员工伤残信息 hasPermission('archives_tempdisabilityinfo_importListAdd')")
	@SysLog("批量新增员工伤残信息")
	@PostMapping("/importListAdd")
	@PreAuthorize("@pms.hasPermission('archives_tempdisabilityinfo_importListAdd')")
	public R<List<ErrorMessage>> importListAdd(@RequestBody MultipartFile file){
		return tEmpDisabilityInfoService.importTmpDisabilityDiy(file.getInputStream());
	}

}
