/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */
package com.yifu.cloud.plus.v1.yifu.social.entity;

import com.alibaba.excel.annotation.ExcelProperty;
import com.alibaba.excel.annotation.write.style.HeadFontStyle;
import com.baomidou.mybatisplus.annotation.*;
import com.yifu.cloud.plus.v1.yifu.common.core.constant.ExcelAttribute;
import com.yifu.cloud.plus.v1.yifu.common.core.constant.ExcelAttributeConstants;
import com.yifu.cloud.plus.v1.yifu.common.mybatis.base.BaseEntity;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.validator.constraints.Length;

import javax.validation.constraints.NotBlank;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 社保公积金查询表
 *
 * @author fxj
 * @date 2022-07-15 11:38:05
 */
@Data
@TableName("t_social_fund_info" )
@EqualsAndHashCode(callSuper = true)
@Schema(description = "社保公积金查询表" )
public class TSocialFundInfo extends BaseEntity {

	/**
	 * id
	 */
	@TableId(type = IdType.ASSIGN_ID)
	@Schema(description = "id" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("id" )
	private String id;
	/**
	 * 员工ID（数据引用）
	 */
	@Length(max = 32, message = "员工ID（数据引用） 不能超过32个字符" )
	@ExcelAttribute(name = "员工ID（数据引用）", maxLength = 32)
	@Schema(description = "员工ID（数据引用）" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("员工ID（数据引用）" )
	private String empId;
	/**
	 * 员工编码
	 */
	@Length(max = 50, message = "员工编码 不能超过50个字符" )
	@ExcelAttribute(name = "员工编码", maxLength = 50)
	@Schema(description = "员工编码" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("员工编码" )
	private String empNo;
	/**
	 * 员工姓名
	 */
	@Length(max = 50, message = "员工姓名 不能超过50个字符" )
	@ExcelAttribute(name = "员工姓名", maxLength = 50)
	@Schema(description = "员工姓名" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("员工姓名" )
	private String empName;
	/**
	 * 员工身份证
	 */
	@Length(max = 20, message = "身份证号 不能超过20个字符" )
	@ExcelAttribute(name = "身份证号", maxLength = 20)
	@Schema(description = "身份证号" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("身份证号" )
	private String empIdcard;
	/**
	 * 员工类型
	 */
	@Length(max = 32, message = "员工类型 不能超过32个字符" )
	@ExcelAttribute(name = "员工类型", maxLength = 32, isDataId = true, dataType = ExcelAttributeConstants.EMP_NATRUE)
	@Schema(description = "员工类型" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("员工类型" )
	private String empType;
	/**
	 * 项目
	 */
	@Length(max = 32, message = "项目id 不能超过32个字符" )
	@ExcelAttribute(name = "项目id", maxLength = 32)
	@Schema(description = "项目id" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("项目id" )
	private String settleDomain;
	/**
	 * 项目
	 */
	@Length(max = 50, message = "社保项目名称不能超过50个字符" )
	@ExcelAttribute(name = "社保项目名称", maxLength = 50)
	@Schema(description = "社保项目名称" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("社保项目名称" )
	private String settleDomainName;

	/**
	 * 项目编码
	 */
	@Length(max = 50, message = "社保项目编码不能超过50个字符" )
	@ExcelAttribute(name = "社保项目编码", maxLength = 50)
	@Schema(description = "社保项目编码" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("社保项目编码" )
	private String settleDomainCode;
	/**
	 * unitName
	 */
	@Length(max = 50, message = "社保单位名称不能超过50个字符" )
	@ExcelAttribute(name = "社保单位名称", maxLength = 50)
	@Schema(description = "社保单位名称" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("社保单位名称" )
	private String unitName;
	/**
	 * unitId
	 */
	@ExcelAttribute(name = "社保单位id", maxLength = 32)
	@Schema(description = "社保单位id" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("社保单位id" )
	private String unitId;

	/**
	 * 项目-公积金
	 */
	@ExcelAttribute(name = "公积金项目id", maxLength = 32)
	@Schema(description = "公积金项目id" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("公积金项目id" )
	private String settleDomainFund;
	/**
	 * 项目-公积金
	 */
	@ExcelAttribute(name = "公积金项目名称", maxLength = 50)
	@Schema(description = "公积金项目名称" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("公积金项目名称" )
	private String settleDomainNameFund;

	/**
	 * 项目编码-公积金
	 */
	@ExcelAttribute(name = "公积金项目编码", maxLength = 50)
	@Schema(description = "公积金项目编码" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("公积金项目编码" )
	private String settleDomainCodeFund;
	/**
	 * 单位名称-公积金
	 */
	@ExcelAttribute(name = "公积金单位名称", maxLength = 50)
	@Schema(description = "公积金单位名称" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("公积金单位名称" )
	private String unitNameFund;
	/**
	 * 单位ID
	 */
	@ExcelAttribute(name = "公积金单位id", maxLength = 32)
	@Schema(description = "公积金单位id" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("公积金单位id" )
	private String unitIdFund;
	/**
	 * 社保户
	 */
	@Length(max = 32, message = "社保户id 不能超过32个字符" )
	@ExcelAttribute(name = "社保户id", maxLength = 32)
	@Schema(description = "社保户id" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("社保户id" )
	private String socialHousehold;
	/**
	 * 社保户
	 */
	@Length(max = 50, message = "社保户 不能超过50个字符" )
	@ExcelAttribute(name = "社保户", maxLength = 50)
	@Schema(description = "社保户" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("社保户" )
	private String socialHouseholdName;
	/**
	 * 缴纳地-省
	 */
	@Length(max = 32, message = "缴纳地-省 不能超过32个字符" )
	@ExcelAttribute(name = "缴纳地-省", maxLength = 32)
	@Schema(description = "缴纳地-省" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("缴纳地-省" )
	private String socialProvince;
	/**
	 * 缴纳地-市
	 */
	@Length(max = 32, message = "缴纳地-市 不能超过32个字符" )
	@ExcelAttribute(name = "缴纳地-市", maxLength = 32)
	@Schema(description = "缴纳地-市" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("缴纳地-市" )
	private String socialCity;
	/**
	 * 缴纳地-县
	 */
	@Length(max = 32, message = "缴纳地-县 不能超过32个字符" )
	@ExcelAttribute(name = "缴纳地-县", maxLength = 32)
	@Schema(description = "缴纳地-县" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("缴纳地-县" )
	private String socialTown;
	/**
	 * 公积金户
	 */
	@Length(max = 32, message = "公积金户 不能超过32个字符" )
	@ExcelAttribute(name = "公积金户", maxLength = 32)
	@Schema(description = "公积金户" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("公积金户" )
	private String providentHousehold;
	/**
	 * 公积金户
	 */
	@Length(max = 50, message = "公积金户 不能超过50个字符" )
	@ExcelAttribute(name = "公积金户", maxLength = 50)
	@Schema(description = "公积金户" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("公积金户" )
	private String providentHouseholdName;
	/**
	 * 公积金缴纳地-省
	 */
	@Length(max = 32, message = "公积金缴纳地-省 不能超过32个字符" )
	@ExcelAttribute(name = "公积金缴纳地-省", maxLength = 32)
	@Schema(description = "公积金缴纳地-省" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("公积金缴纳地-省" )
	private String fundProvince;
	/**
	 * 公积金缴纳地-市
	 */
	@Length(max = 32, message = "公积金缴纳地-市 不能超过32个字符" )
	@ExcelAttribute(name = "公积金缴纳地-市", maxLength = 32)
	@Schema(description = "公积金缴纳地-市" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("公积金缴纳地-市" )
	private String fundCity;
	/**
	 * 公积金缴纳地-县
	 */
	@Length(max = 32, message = "公积金缴纳地-县 不能超过32个字符" )
	@ExcelAttribute(name = "公积金缴纳地-县", maxLength = 32)
	@Schema(description = "公积金缴纳地-县" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("公积金缴纳地-县" )
	private String fundTown;
	/**
	 * 社保派增状态：0待审核、1待办理、2办理成功、3部分办理失败、4办理失败 5 审核不通过 6 办理中
	 */
	@Length(max = 1, message = "社保派增状态 不能超过1个字符" )
	@ExcelAttribute(name = "社保派增状态", maxLength = 1)
	@Schema(description = "社保派增状态：0待审核、1待办理、2办理成功、3部分办理失败、4办理失败 、5审核不通过6 办理中" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("社保派增状态" )
	private String socialAddStatus;
	/**
	 * 公积金派增状态：0待审核、1待办理、2办理成功、3办理失败、4审核不通过
	 */
	@Length(max = 1, message = "公积金派增状态 不能超过1个字符" )
	@ExcelAttribute(name = "公积金派增状态", maxLength = 1)
	@Schema(description = "公积金派增状态：0待审核、1待办理、2办理成功、3办理失败、4审核不通过" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("公积金派增状态" )
	private String fundAddStatus;
	/**
	 * 社保派减状态：0待审核、1待办理、2办理成功、3办理失败 4审核不通过
	 */
	@ExcelAttribute(name = "社保派减状态", maxLength = 1)
	@Schema(description = "社保派减状态：0待审核、1待办理、2办理成功、3办理失败 4审核不通过" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("社保派减状态" )
	private String socialReduceStatus;
	/**
	 * 公积金派减状态：0待审核、1待办理、2办理成功、3办理失败
	 */
	@ExcelAttribute(name = "公积金派减状态", maxLength = 1)
	@Schema(description = "公积金派减状态：0待审核、1待办理、2办理成功、3办理失败" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("公积金派减状态" )
	private String fundReduceStatus;
	/**
	 * 社保ID(取值最新社保ID）
	 */
	@Length(max = 32, message = "社保ID(取值最新社保ID） 不能超过32个字符" )
	@ExcelAttribute(name = "社保ID(取值最新社保ID）", maxLength = 32)
	@Schema(description = "社保ID(取值最新社保ID）" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("社保ID(取值最新社保ID）" )
	private String socialId;
	/**
	 * 公积金ID （取值最新公积金ID）
	 */
	@Length(max = 32, message = "公积金ID （取值最新公积金ID） 不能超过32个字符" )
	@ExcelAttribute(name = "公积金ID （取值最新公积金ID）", maxLength = 32)
	@Schema(description = "公积金ID （取值最新公积金ID）" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("公积金ID （取值最新公积金ID）" )
	private String fundId;

	/**
	 * 首次购买时间（第一派单月份）
	 */
	@ExcelAttribute(name = "首次购买时间（第一派单月份）", isDate = true)
	@Schema(description = "首次购买时间（第一派单月份）" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("首次购买时间（第一派单月份）" )
	private Date firstBuyMonthSocial;
	/**
	 * 单位养老基数
	 */
	@ExcelAttribute(name = "单位养老基数" )
	@Schema(description = "单位养老基数" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("单位养老基数" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal unitPensionCardinal;
	/**
	 * 单位医疗基数
	 */
	@ExcelAttribute(name = "单位医疗基数" )
	@Schema(description = "单位医疗基数" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("单位医疗基数" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal unitMedicalCardinal;
	/**
	 * 单位失业基数
	 */
	@ExcelAttribute(name = "单位失业基数" )
	@Schema(description = "单位失业基数" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("单位失业基数" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal unitUnemploymentCardinal;
	/**
	 * 单位大病救助基数
	 */
	@ExcelAttribute(name = "单位大病救助基数" )
	@Schema(description = "单位大病救助基数" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("单位大病救助基数" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal unitBigailmentCardinal;
	/**
	 * 单位工伤基数
	 */
	@ExcelAttribute(name = "单位工伤基数" )
	@Schema(description = "单位工伤基数" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("单位工伤基数" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal unitWorkInjuryCardinal;
	/**
	 * 单位生育基数
	 */
	@ExcelAttribute(name = "单位生育基数" )
	@Schema(description = "单位生育基数" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("单位生育基数" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal unitBirthCardinal;
	/**
	 * 个人养老基数
	 */
	@ExcelAttribute(name = "个人养老基数" )
	@Schema(description = "个人养老基数" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("个人养老基数" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal personalPensionCardinal;
	/**
	 * 个人医疗基数
	 */
	@ExcelAttribute(name = "个人医疗基数" )
	@Schema(description = "个人医疗基数" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("个人医疗基数" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal personalMedicalCardinal;
	/**
	 * 个人大病救助基数
	 */
	@ExcelAttribute(name = "个人大病救助基数" )
	@Schema(description = "个人大病救助基数" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("个人大病救助基数" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal personalBigailmentCardinal;
	/**
	 * 个人失业基数
	 */
	@ExcelAttribute(name = "个人失业基数" )
	@Schema(description = "个人失业基数" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("个人失业基数" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal personalUnemploymentCardinal;
	/**
	 * 单位工伤基数
	 */
	@ExcelAttribute(name = "单位工伤基数" )
	@Schema(description = "单位工伤基数" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("单位工伤基数" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal personalWorkInjuryCardinal;
	/**
	 * 单位养老比例
	 */
	@ExcelAttribute(name = "单位养老比例" )
	@Schema(description = "单位养老比例" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("单位养老比例" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal unitPensionPer;
	/**
	 * 单位医疗比例
	 */
	@ExcelAttribute(name = "单位医疗比例" )
	@Schema(description = "单位医疗比例" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("单位医疗比例" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal unitMedicalPer;
	/**
	 * 单位失业比例
	 */
	@ExcelAttribute(name = "单位失业比例" )
	@Schema(description = "单位失业比例" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("单位失业比例" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal unitUnemploymentPer;
	/**
	 * 单位工伤比例
	 */
	@ExcelAttribute(name = "单位工伤比例" )
	@Schema(description = "单位工伤比例" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("单位工伤比例" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal unitWorkUnjuryPer;
	/**
	 * 单位生育比例
	 */
	@ExcelAttribute(name = "单位生育比例" )
	@Schema(description = "单位生育比例" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("单位生育比例" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal unitBirthPer;
	/**
	 * 个人养老比例
	 */
	@ExcelAttribute(name = "个人养老比例" )
	@Schema(description = "个人养老比例" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("个人养老比例" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal personalPensionPer;
	/**
	 * 个人医疗比例
	 */
	@ExcelAttribute(name = "个人医疗比例" )
	@Schema(description = "个人医疗比例" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("个人医疗比例" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal personalMedicalPer;
	/**
	 * 个人失业比例
	 */
	@ExcelAttribute(name = "个人失业比例" )
	@Schema(description = "个人失业比例" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("个人失业比例" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal personalUnemploymentPer;
	/**
	 * 办理状态
	 */
	@NotBlank(message = "办理状态不能为空" )
	@Length(max = 32, message = "办理状态 不能超过32个字符" )
	@ExcelAttribute(name = "办理状态", isNotEmpty = true, errorInfo = "办理状态不能为空", maxLength = 32)
	@Schema(description = "办理状态" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("办理状态" )
	private String handleStatus;
	/**
	 * 个人大病比例
	 */
	@ExcelAttribute(name = "个人大病比例" )
	@Schema(description = "个人大病比例" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("个人大病比例" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal personalBigailmentPer;
	/**
	 * 单位大病救助比例
	 */
	@ExcelAttribute(name = "单位大病救助比例" )
	@Schema(description = "单位大病救助比例" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("单位大病救助比例" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal unitBigailmentPer;
	/**
	 * 社保停缴日期
	 * 社保减少日期
	 */
	@ExcelAttribute(name = "社保停缴日期", isDate = true)
	@Schema(description = "社保停缴日期" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("社保停缴日期" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private Date socialReduceDate;
	/**
	 * 是否可补缴 0：是，1：否
	 */
	@Length(max = 1, message = "是否可补缴 0：是，1：否 不能超过1个字符" )
	@ExcelAttribute(name = "是否可补缴 0：是，1：否", maxLength = 1)
	@Schema(description = "是否可补缴 0：是，1：否" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("是否可补缴 0：是，1：否" )
	private String canOverpay;
	/**
	 * 补缴政策（社保或公积金）
	 */
	@Length(max = 500, message = "补缴政策（社保或公积金） 不能超过500个字符" )
	@ExcelAttribute(name = "补缴政策（社保或公积金）", maxLength = 500)
	@Schema(description = "补缴政策（社保或公积金）" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("补缴政策（社保或公积金）" )
	private String payPolicy;
	/**
	 * 补缴期限
	 */
	@ExcelAttribute(name = "补缴期限" )
	@Schema(description = "补缴期限" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("补缴期限" )
	private Integer overpayNumber;
	/**
	 * 是否含当月 0：是，1：否
	 */
	@Length(max = 1, message = "是否含当月 0：是，1：否 不能超过1个字符" )
	@ExcelAttribute(name = "是否含当月 0：是，1：否", maxLength = 1)
	@Schema(description = "是否含当月 0：是，1：否" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("是否含当月 0：是，1：否" )
	private String haveThisMonth;
	/**
	 * 是否能补缴养老0是1否
	 */
	@Length(max = 1, message = "是否能补缴养老0是1否 不能超过1个字符" )
	@ExcelAttribute(name = "是否能补缴养老0是1否", maxLength = 1)
	@Schema(description = "是否能补缴养老0是1否" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("是否能补缴养老0是1否" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private String insurancePension;
	/**
	 * 是否能补缴医疗0是1否
	 */
	@Length(max = 1, message = "是否能补缴医疗0是1否 不能超过1个字符" )
	@ExcelAttribute(name = "是否能补缴医疗0是1否", maxLength = 1)
	@Schema(description = "是否能补缴医疗0是1否" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("是否能补缴医疗0是1否" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private String insuranceMedical;
	/**
	 * 是否能补缴失业0是1否
	 */
	@Length(max = 1, message = "是否能补缴失业0是1否 不能超过1个字符" )
	@ExcelAttribute(name = "是否能补缴失业0是1否", maxLength = 1)
	@Schema(description = "是否能补缴失业0是1否" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("是否能补缴失业0是1否" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private String insuranceUnemployment;
	/**
	 * 是否能补缴工伤0是1否
	 */
	@Length(max = 1, message = "是否能补缴工伤0是1否 不能超过1个字符" )
	@ExcelAttribute(name = "是否能补缴工伤0是1否", maxLength = 1)
	@Schema(description = "是否能补缴工伤0是1否" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("是否能补缴工伤0是1否" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private String insuranceInjury;
	/**
	 * 是否能补缴生育0是1否
	 */
	@Length(max = 1, message = "是否能补缴生育0是1否 不能超过1个字符" )
	@ExcelAttribute(name = "是否能补缴生育0是1否", maxLength = 1)
	@Schema(description = "是否能补缴生育0是1否" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("是否能补缴生育0是1否" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private String insuranceBirth;
	/**
	 * 是否能补缴大病0是1否
	 */
	@Length(max = 1, message = "是否能补缴大病0是1否 不能超过1个字符" )
	@ExcelAttribute(name = "是否能补缴大病0是1否", maxLength = 1)
	@Schema(description = "是否能补缴大病0是1否" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("是否能补缴大病0是1否" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private String insuranceBigailment;
	/**
	 * 补缴是否采用最新基数0是1否
	 */
	@Length(max = 1, message = "补缴是否采用最新基数0是1否 不能超过1个字符" )
	@ExcelAttribute(name = "补缴是否采用最新基数0是1否", maxLength = 1)
	@Schema(description = "补缴是否采用最新基数0是1否" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("补缴是否采用最新基数0是1否" )
	private String latestCardinality;
	/**
	 * 大病是否收费：0收取；1不收取
	 */
	@Length(max = 1, message = "大病是否收费：0收取；1不收取 不能超过1个字符" )
	@ExcelAttribute(name = "大病是否收费：0收取；1不收取", maxLength = 1)
	@Schema(description = "大病是否收费：0收取；1不收取" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("大病是否收费：0收取；1不收取" )
	private String isIllness;
	/**
	 * 大病缴纳周期：0按年1按月
	 */
	@Length(max = 1, message = "大病缴纳周期：0按年1按月 不能超过1个字符" )
	@ExcelAttribute(name = "大病缴纳周期：0按年1按月", maxLength = 1)
	@Schema(description = "大病缴纳周期：0按年1按月" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("大病缴纳周期：0按年1按月" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private String collectType;
	/**
	 * 大病取值方式0按定值 1按比例
	 */
	@Length(max = 1, message = "大病取值方式0按定值 1按比例 不能超过1个字符" )
	@ExcelAttribute(name = "大病取值方式0按定值 1按比例", maxLength = 1)
	@Schema(description = "大病取值方式0按定值 1按比例" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("大病取值方式0按定值 1按比例 " )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private String valueType;
	/**
	 * 大病按年收收取月份1-12月
	 */
	@ExcelAttribute(name = "大病按年收收取月份1-12月" )
	@Schema(description = "大病按年收收取月份1-12月" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("大病按年收收取月份1-12月" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private Integer collectMoth;
	/**
	 * 收费模式：0立即收，1次年收，对应旧值新员工入职收费：0是1否
	 */
	@Length(max = 1, message = "收费模式：0立即收，1次年收，对应旧值新员工入职收费：0是1否 不能超过1个字符" )
	@ExcelAttribute(name = "收费模式：0立即收，1次年收，对应旧值新员工入职收费：0是1否", maxLength = 1)
	@Schema(description = "收费模式：0立即收，1次年收，对应旧值新员工入职收费：0是1否" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("收费模式：0立即收，1次年收，对应旧值新员工入职收费：0是1否" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private String isChargePersonal;
	/**
	 * 备案基数
	 */
	@Length(max = 255, message = "备案基数 不能超过255个字符" )
	@ExcelAttribute(name = "备案基数", maxLength = 255)
	@Schema(description = "备案基数" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("备案基数" )
	private String recordBase;
	/**
	 * 委托备注
	 */
	@Length(max = 100, message = "委托备注 不能超过100个字符" )
	@ExcelAttribute(name = "委托备注", maxLength = 100)
	@Schema(description = "委托备注" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("委托备注" )
	private String trustRemark;
	/**
	 * 缴纳类型（0最低、1自定义缴纳、2最高）
	 */
	@Length(max = 1, message = "缴纳类型（0最低、1自定义、2最高） 不能超过1个字符" )
	@ExcelAttribute(name = "缴纳类型（0最低、1自定义、2最高）", maxLength = 1)
	@Schema(description = "缴纳类型（0最低、1自定义、2最高）" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("缴纳类型（0最低、1自定义、2最高）" )
	private String paymentType;
	/**
	 * 基数上限（社保或公积金）
	 */
	@ExcelAttribute(name = "基数上限（社保或公积金）" )
	@Schema(description = "基数上限（社保或公积金）" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("基数上限（社保或公积金）" )
	private BigDecimal upperLimit;
	/**
	 * 基数下限（社保或公积金）
	 */
	@ExcelAttribute(name = "基数下限（社保或公积金）" )
	@Schema(description = "基数下限（社保或公积金）" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("基数下限（社保或公积金）" )
	private BigDecimal lowerLimit;
	/**
	 * 养老起缴日期
	 */
	@ExcelAttribute(name = "养老起缴日期", isDate = true)
	@Schema(description = "养老起缴日期" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("养老起缴日期" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private Date pensionStart;
	/**
	 * 医疗起缴日期
	 */
	@ExcelAttribute(name = "医疗起缴日期", isDate = true)
	@Schema(description = "医疗起缴日期" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("医疗起缴日期" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private Date medicalStart;
	/**
	 * 失业起缴日期
	 */
	@ExcelAttribute(name = "失业起缴日期", isDate = true)
	@Schema(description = "失业起缴日期" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("失业起缴日期" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private Date unemployStart;
	/**
	 * 工伤起缴日期
	 */
	@ExcelAttribute(name = "工伤起缴日期", isDate = true)
	@Schema(description = "工伤起缴日期" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("工伤起缴日期" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private Date workInjuryStart;
	/**
	 * 生育起缴日期
	 */
	@ExcelAttribute(name = "生育起缴日期", isDate = true)
	@Schema(description = "生育起缴日期" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("生育起缴日期" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private Date birthStart;
	/**
	 * 大病起缴日期
	 */
	@ExcelAttribute(name = "大病起缴日期", isDate = true)
	@Schema(description = "大病起缴日期" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("大病起缴日期" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private Date bigailmentStart;
	/**
	 * 养老办理状态：0待办理1办理成功2办理失败3已派减
	 */
	@Length(max = 1, message = "养老办理状态：0待办理1办理成功2办理失败3已派减 不能超过1个字符" )
	@ExcelAttribute(name = "养老办理状态：0待办理1办理成功2办理失败3已派减", maxLength = 1)
	@Schema(description = "养老办理状态：0待办理1办理成功2办理失败3已派减" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("养老办理状态：0待办理1办理成功2办理失败3已派减" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private String pensionHandle;
	/**
	 * 医疗办理状态：0待办理1办理成功2办理失败3已派减
	 */
	@Length(max = 1, message = "医疗办理状态：0待办理1办理成功2办理失败3已派减 不能超过1个字符" )
	@ExcelAttribute(name = "医疗办理状态：0待办理1办理成功2办理失败3已派减", maxLength = 1)
	@Schema(description = "医疗办理状态：0待办理1办理成功2办理失败3已派减" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("医疗办理状态：0待办理1办理成功2办理失败3已派减" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private String medicalHandle;
	/**
	 * 失业办理状态：0待办理1办理成功2办理失败3已派减
	 */
	@Length(max = 1, message = "失业办理状态：0待办理1办理成功2办理失败3已派减 不能超过1个字符" )
	@ExcelAttribute(name = "失业办理状态：0待办理1办理成功2办理失败3已派减", maxLength = 1)
	@Schema(description = "失业办理状态：0待办理1办理成功2办理失败3已派减" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("失业办理状态：0待办理1办理成功2办理失败3已派减" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private String unemployHandle;
	/**
	 * 工伤办理状态：0待办理1办理成功2办理失败3已派减
	 */
	@Length(max = 1, message = "工伤办理状态：0待办理1办理成功2办理失败3已派减 不能超过1个字符" )
	@ExcelAttribute(name = "工伤办理状态：0待办理1办理成功2办理失败3已派减", maxLength = 1)
	@Schema(description = "工伤办理状态：0待办理1办理成功2办理失败3已派减" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("工伤办理状态：0待办理1办理成功2办理失败3已派减" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private String workInjuryHandle;
	/**
	 * 生育办理状态：0待办理1办理成功2办理失败3已派减
	 */
	@Length(max = 1, message = "生育办理状态：0待办理1办理成功2办理失败3已派减 不能超过1个字符" )
	@ExcelAttribute(name = "生育办理状态：0待办理1办理成功2办理失败3已派减", maxLength = 1)
	@Schema(description = "生育办理状态：0待办理1办理成功2办理失败3已派减" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("生育办理状态：0待办理1办理成功2办理失败3已派减" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private String birthHandle;
	/**
	 * 大病办理状态：0待办理1办理成功2办理失败3已派减
	 */
	@Length(max = 1, message = "大病办理状态：0待办理1办理成功2办理失败3已派减 不能超过1个字符" )
	@ExcelAttribute(name = "大病办理状态：0待办理1办理成功2办理失败3已派减", maxLength = 1)
	@Schema(description = "大病办理状态：0待办理1办理成功2办理失败3已派减" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("大病办理状态：0待办理1办理成功2办理失败3已派减" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private String bigailmentHandle;
	/**
	 * 单位养老金额
	 */
	@ExcelAttribute(name = "单位养老金额" )
	@Schema(description = "单位养老金额" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("单位养老金额" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal unitPersionMoney;
	/**
	 * 单位医疗金额
	 */
	@ExcelAttribute(name = "单位医疗金额" )
	@Schema(description = "单位医疗金额" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("单位医疗金额" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal unitMedicalMoney;
	/**
	 * 单位失业
	 */
	@ExcelAttribute(name = "单位失业" )
	@Schema(description = "单位失业" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("单位失业" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal unitUnemploymentMoney;
	/**
	 * 单位工伤金额
	 */
	@ExcelAttribute(name = "单位工伤金额" )
	@Schema(description = "单位工伤金额" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("单位工伤金额" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal unitInjuryMoney;
	/**
	 * 单位生育金额
	 */
	@ExcelAttribute(name = "单位生育金额" )
	@Schema(description = "单位生育金额" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("单位生育金额" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal unitBirthMoney;
	/**
	 * 单位大病救助金额
	 */
	@ExcelAttribute(name = "单位大病救助金额" )
	@Schema(description = "单位大病救助金额" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("单位大病救助金额" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal unitBigailmentMoney;
	/**
	 * 个人养老金额
	 */
	@ExcelAttribute(name = "个人养老金额" )
	@Schema(description = "个人养老金额" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("个人养老金额" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal personalPersionMoney;
	/**
	 * 个人医疗金额
	 */
	@ExcelAttribute(name = "个人医疗金额" )
	@Schema(description = "个人医疗金额" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("个人医疗金额" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal personalMedicalMoney;
	/**
	 * 个人失业金额
	 */
	@ExcelAttribute(name = "个人失业金额" )
	@Schema(description = "个人失业金额" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("个人失业金额" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal personalUnemploymentMoney;
	/**
	 * 个人大病金额
	 */
	@ExcelAttribute(name = "个人大病金额" )
	@Schema(description = "个人大病金额" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("个人大病金额" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private BigDecimal personalBigailmentMoney;
	/**
	 * 单位公积金缴纳基数
	 */
	@NotBlank(message = "单位公积金缴纳基数不能为空" )
	@ExcelAttribute(name = "单位公积金缴纳基数", isNotEmpty = true, errorInfo = "单位公积金缴纳基数不能为空" )
	@Schema(description = "单位公积金缴纳基数" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("单位公积金缴纳基数" )
	private BigDecimal unitProvidengCardinal;
	/**
	 * 个人公积金缴纳基数
	 */
	@NotBlank(message = "个人公积金缴纳基数不能为空" )
	@ExcelAttribute(name = "个人公积金缴纳基数", isNotEmpty = true, errorInfo = "个人公积金缴纳基数不能为空" )
	@Schema(description = "个人公积金缴纳基数" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("个人公积金缴纳基数" )
	private BigDecimal personalProvidentCardinal;
	/**
	 * 社保起缴日期
	 */
	@ExcelAttribute(name = "社保起缴日期", isDate = true)
	@Schema(description = "社保起缴日期" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("社保起缴日期" )
	private Date socialStartDate;
	/**
	 * 单位公积金缴纳比例
	 */
	@ExcelAttribute(name = "单位公积金缴纳比例" )
	@Schema(description = "单位公积金缴纳比例" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("单位公积金缴纳比例" )
	private BigDecimal unitProvidentPer;
	/**
	 * 个人公积金缴纳比例
	 */
	@ExcelAttribute(name = "个人公积金缴纳比例" )
	@Schema(description = "个人公积金缴纳比例" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("个人公积金缴纳比例" )
	private BigDecimal personalProvidentPer;
	/**
	 * 公积金起缴日期
	 */
	@ExcelAttribute(name = "公积金起缴日期", isDate = true)
	@Schema(description = "公积金起缴日期" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("公积金起缴日期" )
	private Date providentStart;
	/**
	 * 公积金初次购买月份
	 */
	@ExcelAttribute(name = "公积金初次购买月份", isDate = true)
	@Schema(description = "公积金初次购买月份" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("公积金初次购买月份" )
	private Date firstBuyMothFund;
	/**
	 * 基数上限（公积金）
	 */
	@ExcelAttribute(name = "基数上限（公积金）" )
	@Schema(description = "基数上限（公积金）" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("基数上限（公积金）" )
	private BigDecimal upperLimitFund;
	/**
	 * 基数下限（公积金）
	 */
	@ExcelAttribute(name = "基数下限（公积金）" )
	@Schema(description = "基数下限（公积金）" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("基数下限（公积金）" )
	private BigDecimal lowerLimitFund;
	/**
	 * 单边小数点 ，如：四舍五入、见角进元等
	 */
	@Length(max = 1, message = "单边小数点 ，如：四舍五入、见角进元等 不能超过1个字符" )
	@ExcelAttribute(name = "单边小数点 ，如：四舍五入、见角进元等", maxLength = 1)
	@Schema(description = "单边小数点 ，如：四舍五入、见角进元等" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("单边小数点 ，如：四舍五入、见角进元等" )
	private String fundPayPoint;
	/**
	 * 是否可补缴 0：是，1：否(公积金)
	 */
	@Length(max = 1, message = "是否可补缴 0：是，1：否(公积金) 不能超过1个字符" )
	@ExcelAttribute(name = "是否可补缴 0：是，1：否(公积金)", maxLength = 1)
	@Schema(description = "是否可补缴 0：是，1：否(公积金)" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("是否可补缴 0：是，1：否(公积金)" )
	private String canOverpayFund;
	/**
	 * 补缴期限(公积金)
	 */
	@ExcelAttribute(name = "补缴期限(公积金)" )
	@Schema(description = "补缴期限(公积金)" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("补缴期限(公积金)" )
	private Integer overpayNumberFund;
	/**
	 * 补缴政策（公积金）
	 */
	@Length(max = 500, message = "补缴政策（公积金） 不能超过500个字符" )
	@ExcelAttribute(name = "补缴政策（公积金）", maxLength = 500)
	@Schema(description = "补缴政策（公积金）" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("补缴政策（公积金）" )
	private String payPolicyFund;
	/**
	 * 委托备注(公积金)
	 */
	@Length(max = 100, message = "委托备注(公积金) 不能超过100个字符" )
	@ExcelAttribute(name = "委托备注(公积金)", maxLength = 100)
	@Schema(description = "委托备注(公积金)" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("委托备注(公积金)" )
	private String trustRemarkFund;
	/**
	 * 是否含当月 0：是，1：否(公积金)
	 */
	@Length(max = 1, message = "是否含当月 0：是，1：否(公积金) 不能超过1个字符" )
	@ExcelAttribute(name = "是否含当月 0：是，1：否(公积金)", maxLength = 1)
	@Schema(description = "是否含当月 0：是，1：否(公积金)" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("是否含当月 0：是，1：否(公积金)" )
	private String haveThisMonthFund;
	/**
	 * 补缴是否采用最新基数0是1否(公积金)
	 */
	@Length(max = 1, message = "补缴是否采用最新基数0是1否(公积金) 不能超过1个字符" )
	@ExcelAttribute(name = "补缴是否采用最新基数0是1否(公积金)", maxLength = 1)
	@Schema(description = "补缴是否采用最新基数0是1否(公积金)" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("补缴是否采用最新基数0是1否(公积金)" )
	private String latestCardinalityFund;

	/**
	 * 公积金停缴日期
	 */
	@ExcelAttribute(name = "公积金停缴日期", isDate = true)
	@Schema(description = "公积金停缴日期" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("公积金停缴日期" )
	@TableField(updateStrategy = FieldStrategy.IGNORED)
	private Date fundReduceDate;

	/**
	 * 单位补缴利息
	 */
	@ExcelAttribute(name = "单位补缴利息")
	@Schema(description = "单位补缴利息")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("单位补缴利息")
	private BigDecimal unitInterestFee;
	/**
	 * 个人补缴利息
	 */
	@ExcelAttribute(name = "个人补缴利息")
	@Schema(description = "个人补缴利息")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("个人补缴利息")
	private BigDecimal personalInterestFee;

	/**
	 * 单位社保合计
	 */
	@ExcelAttribute(name = "单位社保合计" )
	@Schema(description ="单位社保合计")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("单位社保合计")
	private BigDecimal unitSocialSum;

	/**
	 * 个人社保合计
	 */
	@ExcelAttribute(name = "个人社保合计" )
	@Schema(description ="个人社保合计")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("个人社保合计")
	private BigDecimal personalSocialSum;

	/**
	 * 单位公积金金额
	 */
	@ExcelAttribute(name = "单位公积金金额")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("单位公积金金额")
	private BigDecimal unitFundSum;
	/**
	 * 个人公积金金额
	 */
	@ExcelAttribute(name = "个人公积金金额")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("个人公积金金额")
	private BigDecimal personalFundSum;

	/**
	 * 社保状态：派增（0待审核、1待办理、2办理中 3办理成功、4部分办理失败 5 办理失败 10 审核不通过）、派减（6待审核 7待办理 8办理成功 9 办理失败 ）
	 */
	@ExcelAttribute(name = "社保状态", maxLength = 1)
	@Schema(description = "社保状态：派增（0待审核、1待办理、2办理中 3办理成功、4部分办理失败 5 办理失败 10 审核不通过）、派减（6待审核 7待办理 8办理成功 9 办理失败）" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("社保派增状态" )
	private String socialStatus;
	/**
	 * 公积金状态：派增（0待审核、1待办理、3办理成功、4办理失败9 审核不通过）、派减（5待审核 6待办理 7 办理成功 8 办理失败 ）
	 */
	@Length(max = 1, message = "公积金状态 不能超过1个字符" )
	@ExcelAttribute(name = "公积金状态", maxLength = 1)
	@Schema(description = "公积金状态：派增（0待审核、1待办理、3办理成功、4办理失败9 审核不通过）、派减（5待审核 6待办理 7 办理成功 8 办理失败 ）" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("公积金状态" )
	private String fundStatus;

	/**
	 * 派单ID （实时更新）
	 */
	@ExcelAttribute(name = "派单ID", maxLength = 32)
	@Schema(description = "派单ID" )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("派单ID" )
	private String dispatchId;

	// 执行月份，整体调基使用的
	@TableField(exist = false)
	private String doMonth;
	// 基数配置，户调基使用的
	@TableField(exist = false)
	private SysBaseSetInfo socialSetInfo;
	@TableField(exist = false)
	private SysBaseSetInfo fundSetInfo;
}
